Add base Y2 colors
add_colors_internal_y2.Rd3 Y2 colors: BLUE, GRAY and ORANGE
Arguments
- palette
DEFAULT = 1. Defaults to the newest Y2 color palette (1). Switch between the latest color palette and older color palettes, with 1 being the oldest. Currently only 1 available.
- compliments
DEFAULT = FALSE. Add complimentary colors chosen by the Y2 team (Red, Pink, Yellow, Green, Turquoise)
- show_colors
DEFAULT = TRUE Show the color palettes loaded into your environment